import React from 'react';
import styles from './App.module.css';
import GamePanel from './components/screens/GamePanel';
import HomePage from './components/screens/HomePage';
import Lobby from './components/screens/Lobby';
import PlayerScores from './components/screens/PlayerScores';
import RoundSummary from './components/screens/RoundSummary';
import ApiInfo from './components/util/ApiInfo';
import { ERROR, IN_ROUND, POST_GAME, POST_ROUND, PRE_GAME, PRE_ROUND } from './domain/GameState';
import { useGameState } from './domain/gameStore';
import useDirectGameLinks from './hooks/useDirectGameLinks';

const screenMap = {
  [PRE_GAME]: HomePage,
  [PRE_ROUND]: Lobby,
  [IN_ROUND]: GamePanel,
  [POST_ROUND]: RoundSummary,
  [POST_GAME]: PlayerScores,
  [ERROR]: () => <p>Application encountered unrecoverable error, please refresh the page.</p>
};

const needsHeaderFooter = {
  [PRE_GAME]: true,
  [PRE_ROUND]: true,
  [IN_ROUND]: false,
  [POST_ROUND]: false,
  [POST_GAME]: false,
  [ERROR]: true
};

export default () => {
  const gameState = useGameState();
  useDirectGameLinks();
  const Screen = screenMap[gameState];
  const needsHF = needsHeaderFooter[gameState];

  return (
    <React.StrictMode>
      <div className={styles.page}>
        {needsHF && (
          <div className={styles.header}>
            <p>TerrAssumptions!</p>
          </div>
        )}
        <Screen />
        {needsHF && (
          <div className={styles.footer}>
            <ApiInfo />
          </div>
        )}
      </div>
    </React.StrictMode>
  );
};
