import React from 'react';
import { useGameId } from '../../../domain/gameStore';
import { useGameCoords, useLinkedGame, usePlayers } from '../../../hooks/useGameInfo';
import ClickToCopy from '../../util/ClickToCopy';
import Loading from '../../util/Loading';
import LinkedGame from './LinkedGame';
import styles from './PlayerScores.module.css';
import PlayerScoreTile from './PlayerScoreTile';
import SummaryMap from './SummaryMap';

const ScoreBoard = ({ players }) => (
  <div className={styles.scoreboard}>
    {players
      .filter(({ currentRound }) => currentRound === null)
      .sort((p1, p2) => (p1.totalScore > p2.totalScore ? -1 : p1.totalScore < p2.totalScore ? 1 : 0))
      .map((data) => <PlayerScoreTile key={data.name} {...data} />)}
  </div>
);

export default () => {
  // poll the game state
  const gameId = useGameId();
  const coords = useGameCoords();
  const players = usePlayers();
  const linkedGame = useLinkedGame();

  // set up the summary URL
  const summaryURL = new URL(window.location.href);
  summaryURL.searchParams.append('summary', gameId);

  if (!players || !coords) {
    return <Loading />;
  }

  return (
    <div className={styles.page}>
      <div className={styles.top}>
        <SummaryMap {...{ players, coords }} />
        <LinkedGame {...{ linkedGame, gameId }} />
      </div>
      <ScoreBoard {...{ players }} />
      <span className={styles.label}>
        <ClickToCopy text={summaryURL.href}>Click here to copy a link to this summary!</ClickToCopy>
      </span>
    </div>
  );
};
