import ms from 'pretty-ms';
import React, { useState } from 'react';
import { createGame } from '../../../domain/apiMethods';
import { MAP_CRUNCH, RANDOM_STREET_VIEW, URBAN } from '../../../domain/genMethods';
import Loading from '../Loading';
import { Dropdown, Item } from './Dropdown';
import styles from './GameCreationForm.module.css';

export default ({ afterCreate }) => {
  const [ loading, setLoading ] = useState(false);
  const [ timer, setTimer ] = useState(300);
  const [ rounds, setRounds ] = useState(5);
  const [ onlyAmerica, setOnlyAmerica ] = useState(false);
  const [ genMethod, setGenMethod ] = useState(MAP_CRUNCH);

  if (loading) {
    return <Loading />;
  }

  const invalidCombo = genMethod === URBAN && onlyAmerica;

  const onCreateGame = async () => {
    setLoading(true);
    const gameId = await createGame(timer, rounds, onlyAmerica, genMethod);
    if (afterCreate) {
      afterCreate(gameId);
    }
  };

  return (
    <div className={styles.form}>
      <div className={styles.dropdowns}>
        <Dropdown selected={`Round Timer: ${ms(timer * 1000)}`} onSelect={setTimer}>
          <Item value={30}>30 Seconds</Item>
          <Item value={120}>2 Minutes</Item>
          <Item value={300}>5 Minutes</Item>
          <Item value={3600}>1 Hour</Item>
        </Dropdown>
        <Dropdown selected={`Rounds: ${rounds}`} onSelect={setRounds}>
          <Item value={1}>1 Round</Item>
          <Item value={3}>3 Rounds</Item>
          <Item value={5}>5 Rounds</Item>
          <Item value={10}>10 Rounds</Item>
        </Dropdown>
        <Dropdown selected={onlyAmerica ? 'Just America' : 'All Countries'} onSelect={setOnlyAmerica}>
          <Item value={false}>All Countries</Item>
          <Item value={true}>Just America</Item>
        </Dropdown>
        <Dropdown selected={`Generator: ${genMethod === MAP_CRUNCH ? 'Map Crunch' : genMethod === RANDOM_STREET_VIEW ? 'RSV' : 'Urban Centers'}`} onSelect={setGenMethod}>
          <Item value={MAP_CRUNCH}>Map Crunch</Item>
          <Item value={RANDOM_STREET_VIEW}>Random Street View</Item>
          <Item value={URBAN}>Urban Centers</Item>
        </Dropdown>
      </div>
      <button className={styles.start} onClick={onCreateGame} disabled={invalidCombo}>
        {invalidCombo ? 'Incompatible Options' : 'New Game'}
      </button>
    </div>
  );
};
